<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" 
	xmlns:eCH-0007="http://www.ech.ch/xmlns/eCH-0007-f/5" 
	xmlns:eCH-0010="http://www.ech.ch/xmlns/eCH-0010-f/5" 
	xmlns:eCH-0011="http://www.ech.ch/xmlns/eCH-0011-f/7" 
	xmlns:eCH-0044="http://www.ech.ch/xmlns/eCH-0044-f/4" 
	xmlns:eCH-0058="http://www.ech.ch/xmlns/eCH-0058/4" 
	xmlns:eahv-iv-common="http://www.eahv-iv.ch/xmlns/eahv-iv-common/4">
	
	<xsl:import href="sedex-id-2-0.xsl"/>
	<xsl:import href="ech-language-2-0_fr.xsl"/>
	<xsl:import href="eahv-iv-common-language-4-0_fr.xsl"/>
	
	
	<!-- Standard decimal format for swiss numbers. Empty numbers are shown 
		as empty. -->
	<xsl:decimal-format grouping-separator="'" decimal-separator="." NaN=""/>
	<!-- Format string to use for integers -->
	<xsl:variable name="integer-format">
		###'###'###'###
	</xsl:variable>
	<!-- Format string to use for amounts including cents -->
	<xsl:variable name="cents-format">
		###'###'###'##0.00
	</xsl:variable>
	<!-- Format string to use for percentages. % sign is not added -->
	<xsl:variable name="percent-format">
		###.##
	</xsl:variable>
	<!-- Page margins -->
	<xsl:variable name="page-margins">
		13mm 13mm 8mm 13mm
	</xsl:variable>
	<xsl:variable name="first-header-height">
		0mm
	</xsl:variable>
	<xsl:variable name="header-height">
		11mm
	</xsl:variable>
	<xsl:variable name="footer-height">
		8mm
	</xsl:variable>
	<xsl:variable name="first-body-top-margin">
		0mm
	</xsl:variable>
	<xsl:variable name="body-top-margin">
		11mm
	</xsl:variable>
	<xsl:variable name="body-bottom-margin">
		12mm
	</xsl:variable>
	<!-- Some standard definitions for the layout of data blocks in PDF message 
		layout -->
	<!-- White space between data blocks -->
	<xsl:variable name="space-after-blocks">
		6mm
	</xsl:variable>
	<!-- Font to use -->
	<xsl:variable name="font-family">
		Liberation Sans
	</xsl:variable>
	<!-- Width of the left header column on first page -->
	<xsl:variable name="header-left-column-width">
		92mm
	</xsl:variable>
	<!-- Width of the right header column on first page -->
	<xsl:variable name="header-right-column-width">
		proportional-column-width(1)
	</xsl:variable>
	<!-- Width of the title column (leftmost column of a data block) -->
	<xsl:variable name="title-column-width">
		38mm
	</xsl:variable>
	<!-- Width of the description column (second column of a data block) -->
	<xsl:variable name="description-column-width">
		50mm
	</xsl:variable>
	<!-- Width of the description column (second column of a data block), when 
		in a table -->
	<xsl:variable name="description-column-table-width"> <!--change width from proportional-column-width(1) to 52mm-->
		52mm
	</xsl:variable>
	<!-- Width of an interest column (showing interest rate) -->
	<xsl:variable name="interest-column-width">
		13mm
	</xsl:variable>
	<!-- Width of value column (showing amounts) -->
	<xsl:variable name="value-column-width">
		25mm
	</xsl:variable>
	<!-- Width of doctype column (showing amounts) -->
	<xsl:variable name="docpath-column-width">
		50mm
	</xsl:variable>
	<!-- Width of doctype column (showing amounts) -->
	<xsl:variable name="doctype-column-width">
		26mm
	</xsl:variable>
	<!-- Colordefinition for grey background -->
	<xsl:variable name="grey-background">
		#cdcdcd
	</xsl:variable>
	<xsl:variable name="lower-case">
		abcdefghijklmnopqrstuvwxyzäöüàéè
	</xsl:variable>
	<xsl:variable name="upper-case">
		ABCDEFGHIJKLMNOPQRSTUVWXYZÄÖÜÀÉÈ
	</xsl:variable>
	<!-- ************* Formatting templates *************** -->
	<!-- Format a date for display in PDF. @param value the date to be formatted 
		(as defined in xs:date) -->
	<xsl:template name="format-date">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="string-length($trimmed-value) > 0">
				<xsl:variable name="year" select="substring($trimmed-value, 1, 4)"/>
				<xsl:variable name="month" select="substring($trimmed-value, 6, 2)"/>
				<xsl:variable name="day" select="substring($trimmed-value, 9, 2)"/>
				<xsl:value-of select="$day"/>.<xsl:value-of select="$month"/>.<xsl:value-of select="$year"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- Format a partially known date for display in PDF. @param value the 
		date to be formatted (as defined in xs:data, xs:gYearMonth, xs:gYear) -->
	<xsl:template name="format-datePartiallyKnownType">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="string-length($trimmed-value) > 7">
				<xsl:call-template name="format-date">
					<xsl:with-param name="value" select="$trimmed-value"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="string-length($trimmed-value) > 4">
				<xsl:variable name="year" select="substring($trimmed-value, 1, 4)"/>
				<xsl:variable name="month" select="substring($trimmed-value, 6, 2)"/>
				<xsl:value-of select="$month"/>.<xsl:value-of select="$year"/>
			</xsl:when>
			<xsl:when test="string-length($trimmed-value) > 0">
				<xsl:value-of select="$trimmed-value"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- Format a vn (=new AHV number), i.e. insert dots where appropriate. 
		@param value vn to format -->
	<xsl:template name="format-vnType">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="string-length($trimmed-value) = 13">
				<xsl:value-of select="substring($trimmed-value, 1, 3)"/>.<xsl:value-of select="substring($trimmed-value, 4, 4)"/>.<xsl:value-of select="substring($trimmed-value, 8, 4)"/>.<xsl:value-of select="substring($trimmed-value, 12, 2)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Format an old AHV number, i.e. insert dots where appropriate. @param 
		value vn to format -->
	<xsl:template name="format-old-ahv">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="string-length($trimmed-value) = 11">
				<xsl:value-of select="substring($trimmed-value, 1, 3)"/>.<xsl:value-of select="substring($trimmed-value, 4, 2)"/>.<xsl:value-of select="substring($trimmed-value, 6, 3)"/>.<xsl:value-of select="substring($trimmed-value, 9, 3)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Format a string, i.e. output the string @param value string to format -->
	<xsl:template name="format-string">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:value-of select="$trimmed-value"/>
	</xsl:template>
	<!-- Format a string as a title, i.e. make sure the first character is upper 
		case @param value string to format -->
	<xsl:template name="format-title">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:variable name="first-char" select="translate(substring($trimmed-value, 1, 1), $lower-case, $upper-case)"/>
		<xsl:value-of select="concat($first-char, substring($trimmed-value, 2))"/>
	</xsl:template>
	<!-- Format a percentage, format a number and append a percent sign. If 
		empty, the empty sign is output instead. @param value string to format @param 
		empty-sign string to output if value is empty -->
	<xsl:template name="format-percent">
		<xsl:param name="value"/>
		<xsl:param name="empty-sign"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="string-length($trimmed-value) > 0">
				<xsl:value-of select="format-number($trimmed-value, $percent-format)"/>
				%
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$empty-sign"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ************* Decodings templates *************** -->
	<!-- Decode an action to a human readable string. @param value the action 
		to be decoded (as defined in ssk/eahv-iv) -->
	<xsl:template name="decode-action">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '1'">
				<xsl:value-of select="$eahv-iv-common.action.1"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '3'">
				<xsl:value-of select="$eahv-iv-common.action.3"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '4'">
				<xsl:value-of select="$eahv-iv-common.action.4"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '5'">
				<xsl:value-of select="$eahv-iv-common.action.5"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '6'">
				<xsl:value-of select="$eahv-iv-common.action.6"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '7'">
				<xsl:value-of select="$eahv-iv-common.action.7"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '8'">
				<xsl:value-of select="$eahv-iv-common.action.8"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '9'">
				<xsl:value-of select="$eahv-iv-common.action.9"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '10'">
				<xsl:value-of select="$eahv-iv-common.action.10"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '11'">
				<xsl:value-of select="$eahv-iv-common.action.11"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '12'">
				<xsl:value-of select="$eahv-iv-common.action.12"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode a MIME type to a human readable string. @param value the type 
		to be decoded -->
	<xsl:template name="decode-mime">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = 'image/tiff'">
				TIFF
			</xsl:when>
			<xsl:when test="$trimmed-value = 'application/pdf'">
				PDF
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode an personIdCategory to a human readable string. @param value 
		the personIdCategory to be decoded (as defined in eCH-0044) -->
	<xsl:template name="decode-personIdCategory">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = 'CH.AHV'">
				<xsl:value-of select="$eCH-0044.personIdCategory.CH.AHV"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode an organisationIdCategory to a human readable string. @param 
		value the organisationIdCategory to be decoded -->
	<xsl:template name="decode-organisationIdCategory">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = 'CH.UID'">
				<xsl:value-of select="$eCH-0097.organisationIdCategory.CH.UID"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'CH.BUR'">
				<xsl:value-of select="$eCH-0097.organisationIdCategory.CH.BUR"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'CH.FTANbr'">
				<xsl:value-of select="$eCH-0097.organisationIdCategory.CH.FTANbr"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'CH.SHAB'">
				<xsl:value-of select="$eCH-0097.organisationIdCategory.CH.SHAB"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode a sex code to a human readable string. @param value the sex 
		to be decoded (as defined in eCH0044-sexType) -->
	<xsl:template name="decode-sexType">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '1'">
				<xsl:value-of select="$eahv-iv-common.sex.1"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '2'">
				<xsl:value-of select="$eahv-iv-common.sex.2"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode a religion code to a human readable string. @param value the 
		religion to be decoded (as defined in eCH0011-religionType) -->
	<xsl:template name="decode-religionType">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '111'">
				<xsl:value-of select="$eahv-iv-common.religion.111"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '121'">
				<xsl:value-of select="$eahv-iv-common.religion.121"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '122'">
				<xsl:value-of select="$eahv-iv-common.religion.122"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '211'">
				<xsl:value-of select="$eahv-iv-common.religion.211"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '711'">
				<xsl:value-of select="$eahv-iv-common.religion.711"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '811'">
				<xsl:value-of select="$eahv-iv-common.religion.811"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '000'">
				<xsl:value-of select="$eahv-iv-common.religion.000"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode a marital status code to a human readable string. @param value 
		the marital status to be decoded (as defined in eCH0011-maritalStatusType) -->
	<xsl:template name="decode-maritalStatusType">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '1'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.1"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '2'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.2"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '3'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.3"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '4'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.4"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '5'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.5"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '6'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.6"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '7'">
				<xsl:value-of select="$eahv-iv-common.maritalStatus.7"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode a legal form code to a human readable string. Unknown values 
		are shown untranslated. @param value the legal form to be decoded (as defined 
		in eCH0097-legalFormType) -->
	<xsl:template name="decode-legalFormType">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '1'">
				<xsl:value-of select="$eahv-iv-common.legalForm.1"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '2'">
				<xsl:value-of select="$eahv-iv-common.legalForm.2"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '3'">
				<xsl:value-of select="$eahv-iv-common.legalForm.3"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '4'">
				<xsl:value-of select="$eahv-iv-common.legalForm.4"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '5'">
				<xsl:value-of select="$eahv-iv-common.legalForm.5"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '6'">
				<xsl:value-of select="$eahv-iv-common.legalForm.6"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '7'">
				<xsl:value-of select="$eahv-iv-common.legalForm.7"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '8'">
				<xsl:value-of select="$eahv-iv-common.legalForm.8"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '9'">
				<xsl:value-of select="$eahv-iv-common.legalForm.9"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '10'">
				<xsl:value-of select="$eahv-iv-common.legalForm.10"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '11'">
				<xsl:value-of select="$eahv-iv-common.legalForm.11"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '12'">
				<xsl:value-of select="$eahv-iv-common.legalForm.12"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '13'">
				<xsl:value-of select="$eahv-iv-common.legalForm.13"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '14'">
				<xsl:value-of select="$eahv-iv-common.legalForm.14"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Decode a type of real estate property to a human readable string. Unknown 
		values are shown untranslated. @param value the type of real estate property 
		to be decoded (as defined in ssk-common) -->
	<xsl:template name="decode-typeOfRealEstateProperty">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '0'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.0"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '1'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.1"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '2'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.2"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '3'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.3"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '4'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.4"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '5'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.5"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '6'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.6"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '7'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.7"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '8'">
				<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty.8"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!--
		Decode a boolean value to a human readable string (yes/no)
		@param value the boolean to be decoded 
	-->
	 <xsl:template name="decode-boolean">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = 'true'"><xsl:value-of select="$eahv-iv-common.yes"/></xsl:when>
			<xsl:when test="$trimmed-value = 'false'"><xsl:value-of select="$eahv-iv-common.no"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="$trimmed-value"/></xsl:otherwise>
		</xsl:choose>
    </xsl:template>
    
	<!-- Decode a direct payment code to a human readable string. Unknown values 
		are shown untranslated. @param value the direct payment to be decoded (as 
		defined in ssk-common) -->
	<xsl:template name="decode-directPayment">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '0'">
				<xsl:value-of select="$eahv-iv-common.directPayment.0"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = '1'">
				<xsl:value-of select="$eahv-iv-common.directPayment.1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$trimmed-value"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ************* Templates specific to PDF message formatting *************** -->
	<!-- attribute set for fixed message header block (denomination column) -->
	<xsl:attribute-set name="header-denom-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
		<xsl:attribute name="border-top-color">black</xsl:attribute>
		<xsl:attribute name="border-top-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-top-style">solid</xsl:attribute>
		<xsl:attribute name="padding-bottom">3mm</xsl:attribute>
		<xsl:attribute name="margin-left">0mm</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for fixed message header block (value column) -->
	<xsl:attribute-set name="header-value-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="padding-bottom">3mm</xsl:attribute>
		<xsl:attribute name="margin-left">1.5mm</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for for the footer -->
	<xsl:attribute-set name="footer">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block left column (block title) -->
	<xsl:attribute-set name="main-left-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
		<xsl:attribute name="margin-left">0mm</xsl:attribute>
		<xsl:attribute name="border-top-color">black</xsl:attribute>
		<xsl:attribute name="border-top-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-top-style">solid</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block right column (block contents of 
		fixed size blocks) -->
	<xsl:attribute-set name="main-right-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="margin-left">1.5mm</xsl:attribute>
		<xsl:attribute name="border-left-color">black</xsl:attribute>
		<xsl:attribute name="border-left-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-left-style">solid</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block (first column, non-first rows of 
		dynamic size blocks) -->
	<xsl:attribute-set name="table-left-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
		<xsl:attribute name="margin-left">0mm</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block (description column for fixed size 
		blocks) -->
	<xsl:attribute-set name="denom-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
		<xsl:attribute name="margin-left">0mm</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block (table column title for dynamic 
		size blocks) -->
	<xsl:attribute-set name="table-title-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
		<xsl:attribute name="margin-left">1.5mm</xsl:attribute>
		<xsl:attribute name="border-top-color">black</xsl:attribute>
		<xsl:attribute name="border-top-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-top-style">solid</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block (description column for dynamic 
		size blocks) -->
	<xsl:attribute-set name="table-denom-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">normal</xsl:attribute>
		<xsl:attribute name="margin-left">1.5mm</xsl:attribute>
		<xsl:attribute name="border-left-color">black</xsl:attribute>
		<xsl:attribute name="border-left-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-left-style">solid</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block (value column) -->
	<xsl:attribute-set name="value-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="margin-left">1.5mm</xsl:attribute>
	</xsl:attribute-set>
	<!-- attribute set for information block (value-like description column 
		for dynamic size blocks) -->
	<xsl:attribute-set name="first-value-column">
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="margin-left">1.5mm</xsl:attribute>
		<xsl:attribute name="border-left-color">black</xsl:attribute>
		<xsl:attribute name="border-left-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-left-style">solid</xsl:attribute>
	</xsl:attribute-set>
	<!-- standard template for a block containing only title and one string -->
	<xsl:template name="single-string-block">
		<xsl:param name="title"/>
		<xsl:param name="value"/>
		<fo:table table-layout="fixed" width="100%" space-after="{$space-after-blocks}" border-collapse="separate">
			<fo:table-column column-width="{$title-column-width}" column-number="1"/>
			<fo:table-column column-width="proportional-column-width(1)" column-number="2"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell column-number="1" xsl:use-attribute-sets="main-left-column">
						<fo:block>
							<xsl:value-of select="$title"/>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell column-number="2" xsl:use-attribute-sets="main-right-column">
						<fo:block>
							<xsl:value-of select="."/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- standard template for a block containing only title and one number -->
	<xsl:template name="single-number-block">
		<xsl:param name="title"/>
		<xsl:param name="value"/>
		<fo:table table-layout="fixed" width="100%" space-after="{$space-after-blocks}" border-collapse="separate">
			<fo:table-column column-width="{$title-column-width}" column-number="1"/>
			<fo:table-column column-width="{$description-column-width}" column-number="2"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell column-number="1" xsl:use-attribute-sets="main-left-column">
						<fo:block>
							<xsl:value-of select="$title"/>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell column-number="2" xsl:use-attribute-sets="main-right-column">
						<fo:block>
							<xsl:value-of select="format-number($value, $integer-format)"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- standard template for a block containing only title and one amount 
		(incl. cents) -->
	<xsl:template name="single-cents-block">
		<xsl:param name="title"/>
		<xsl:param name="value"/>
		<fo:table table-layout="fixed" width="100%" space-after="{$space-after-blocks}" border-collapse="separate">
			<fo:table-column column-width="{$title-column-width}" column-number="1"/>
			<fo:table-column column-width="{$description-column-width}" column-number="2"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell column-number="1" xsl:use-attribute-sets="main-left-column">
						<fo:block>
							<xsl:value-of select="$title"/>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell column-number="2" xsl:use-attribute-sets="main-right-column">
						<fo:block>
							<xsl:value-of select="format-number($value, $cents-format)"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- standard template for a block containing only title and one date -->
	<xsl:template name="single-date-block">
		<xsl:param name="title"/>
		<xsl:param name="value"/>
		<fo:table table-layout="fixed" width="100%" space-after="{$space-after-blocks}" border-collapse="separate">
			<fo:table-column column-width="{$title-column-width}" column-number="1"/>
			<fo:table-column column-width="{$description-column-width}" column-number="2"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell column-number="1" xsl:use-attribute-sets="main-left-column">
						<fo:block>
							<xsl:value-of select="$title"/>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell column-number="2" xsl:use-attribute-sets="main-right-column">
						<fo:block>
							<xsl:call-template name="format-date">
								<xsl:with-param name="value" select="$value"/>
							</xsl:call-template>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- helper template for outputting an eCH-0044:namedPersonIdType on one 
		line -->
	<xsl:template name="format-personId">
		<xsl:param name="id-category"/>
		<xsl:param name="id"/>
		<xsl:choose>
			<xsl:when test="$id-category = 'CH.AHV'">
				<xsl:call-template name="format-old-ahv">
					<xsl:with-param name="value">
						<xsl:value-of select="$id"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="format-string">
					<xsl:with-param name="value">
						<xsl:value-of select="$id"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- helper template for outputting eCH-0044:namedPersonIdType on one line -->
	<xsl:template match="eahv-iv-common:localPersonId | eahv-iv-common:otherPersonId | eahv-iv-common:euPersonId" mode="inline">
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:call-template name="format-personId">
			<xsl:with-param name="id-category">
				<xsl:value-of select="eCH-0044:personIdCategory"/>
			</xsl:with-param>
			<xsl:with-param name="id">
				<xsl:value-of select="eCH-0044:personId"/>
			</xsl:with-param>
		</xsl:call-template>
		(
		<xsl:call-template name="decode-personIdCategory">
			<xsl:with-param name="value">
				<xsl:value-of select="eCH-0044:personIdCategory"/>
			</xsl:with-param>
		</xsl:call-template>
		)
	</xsl:template>
	<!-- helper template for formatting ssk-common.officialName -->
	<xsl:template match="eahv-iv-common:officialName">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.officialName"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.name -->
	<xsl:template match="eahv-iv-common:name">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.name"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.firstName -->
	<xsl:template match="eahv-iv-common:firstName">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.firstName"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.sex -->
	<xsl:template match="eahv-iv-common:sex">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.sex"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="decode-sexType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.dateOfBirth -->
	<xsl:template match="eahv-iv-common:dateOfBirth">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.dateOfBirth"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-datePartiallyKnownType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.vn -->
	<xsl:template match="eahv-iv-common:vn">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.vn"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-vnType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.oldVn -->
	<xsl:template match="eahv-iv-common:oldVn">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.oldVn"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-vnType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for outputting an eCH-0044:namedPersonIdType on multiple 
		lines -->
	<xsl:template match="eahv-iv-common:localPersonId | eahv-iv-common:otherPersonId | eahv-iv-common:euPersonId">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:call-template name="decode-personIdCategory">
						<xsl:with-param name="value">
							<xsl:value-of select="eCH-0044:personIdCategory"/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-personId">
						<xsl:with-param name="id-category">
							<xsl:value-of select="eCH-0044:personIdCategory"/>
						</xsl:with-param>
						<xsl:with-param name="id">
							<xsl:value-of select="eCH-0044:personId"/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for outputting an eCH-0097:namedOrganisationIdType 
		on one line -->
	<xsl:template name="format-organisationId">
		<xsl:param name="id-category"/>
		<xsl:param name="id"/>
		<xsl:choose>
			<xsl:when test="$id-category = ''">
				<!-- format some known category -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="format-string">
					<xsl:with-param name="value">
						<xsl:value-of select="$id"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- helper template for outputting eCH-0097:namedOrganisationIdType on 
		one line -->
	<xsl:template match="eahv-iv-common:localOrganisationId | eahv-iv-common:otherOrganisationId | eahv-iv-common:euOrganisationId" mode="inline">
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:call-template name="format-organisationId">
			<xsl:with-param name="id-category">
				<xsl:value-of select="eahv-iv-common:organisationIdCategory"/>
			</xsl:with-param>
			<xsl:with-param name="id">
				<xsl:value-of select="eahv-iv-common:organisationId"/>
			</xsl:with-param>
		</xsl:call-template>
		(
		<xsl:call-template name="decode-organisationIdCategory">
			<xsl:with-param name="value">
				<xsl:value-of select="eahv-iv-common:organisationIdCategory"/>
			</xsl:with-param>
		</xsl:call-template>
		)
	</xsl:template>
	<!-- helper template for outputting eCH-0097:namedOrganisationIdType on 
		multiple lines -->
	<xsl:template match="eahv-iv-common:localOrganisationId | eahv-iv-common:otherOrganisationId | eahv-iv-common:euOrganisationId">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:call-template name="decode-organisationIdCategory">
						<xsl:with-param name="value">
							<xsl:value-of select="eahv-iv-common:organisationIdCategory"/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-organisationId">
						<xsl:with-param name="id-category">
							<xsl:value-of select="eahv-iv-common:organisationIdCategory"/>
						</xsl:with-param>
						<xsl:with-param name="id">
							<xsl:value-of select="eahv-iv-common:organisationId"/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.organisationName -->
	<xsl:template match="eahv-iv-common:organisationName">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.organisationName"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.dateFounded -->
	<xsl:template match="eahv-iv-common:dateFounded">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.dateFounded"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-datePartiallyKnownType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.legalForm -->
	<xsl:template match="eahv-iv-common:legalForm">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.legalForm"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="decode-legalFormType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.directPayment -->
	<xsl:template match="eahv-iv-common:directPayment">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.directPayment"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="decode-directPayment">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for outputting an address tag (eCH-0010:addressInfoType) 
		on one line -->
	<xsl:template match="eahv-iv-common:address">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.address"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:apply-templates select="*" mode="inline"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="eCH-0010:addressLine1" mode="inline">
		<xsl:value-of select="."/>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="eCH-0010:addressLine2" mode="inline">
		<xsl:if test="position() != 1">
			,
		</xsl:if>
		<xsl:value-of select="."/>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="eCH-0010:street" mode="inline">
		<xsl:if test="position() != 1">
			,
		</xsl:if>
		<xsl:value-of select="."/>
		<xsl:if test="../eCH-0010:houseNumber">
			<xsl:value-of select="concat(' ', ../eCH-0010:houseNumber)"/>
		</xsl:if>
		<xsl:if test="../eCH-0010:dwellingNumber">
			<xsl:value-of select="concat('/', ../eCH-0010:dwellingNumber)"/>
		</xsl:if>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="eCH-0010:postOfficeBoxText" mode="inline">
		<xsl:if test="position() != 1">
			,
		</xsl:if>
		<xsl:value-of select="concat(' ', text())"/>
		<xsl:if test="../eCH-0010:postOfficeBoxNumber">
			<xsl:value-of select="concat(' ', ../eCH-0010:postOfficeBoxNumber)"/>
		</xsl:if>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="eCH-0010:locality" mode="inline">
		<xsl:if test="position() != 1">
			,
		</xsl:if>
		<xsl:value-of select="concat(' ', text())"/>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="eCH-0010:town" mode="inline"> <!-- remove the space before comma-->
		<xsl:if test="position() != 1">,
		</xsl:if>
		<xsl:if test="../eCH-0010:country">
			<xsl:value-of select="concat(../eCH-0010:country, '-')"/>
		</xsl:if>
		<xsl:if test="../eCH-0010:swissZipCode">
			<xsl:value-of select="concat(../eCH-0010:swissZipCode, ' ')"/>
		</xsl:if>
		<xsl:if test="../eCH-0010:foreignZipCode">
			<xsl:value-of select="concat(../eCH-0010:foreignZipCode, ' ')"/>
		</xsl:if>
		<xsl:value-of select="."/>
		<xsl:if test="../eCH-0010:swissZipCodeAddOn">
			<xsl:value-of select="concat(' ', ../eCH-0010:swissZipCodeAddOn)"/>
		</xsl:if>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType on one line -->
	<xsl:template match="*" mode="inline">
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="eCH-0010:addressLine1" mode="block">
		<fo:block>
			<xsl:value-of select="."/>
		</fo:block>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="eCH-0010:addressLine2" mode="block">
		<fo:block>
			<xsl:value-of select="."/>
		</fo:block>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="eCH-0010:street" mode="block">
		<fo:block>
			<xsl:value-of select="."/>
			<xsl:if test="../eCH-0010:houseNumber">
				<xsl:value-of select="concat(' ', ../eCH-0010:houseNumber)"/>
			</xsl:if>
			<xsl:if test="../eCH-0010:dwellingNumber">
				<xsl:value-of select="concat('/', ../eCH-0010:dwellingNumber)"/>
			</xsl:if>
		</fo:block>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="eCH-0010:postOfficeBoxText" mode="block">
		<fo:block>
			<xsl:value-of select="."/>
			<xsl:if test="../eCH-0010:postOfficeBoxNumber">
				<xsl:value-of select="concat(' ', ../eCH-0010:postOfficeBoxNumber)"/>
			</xsl:if>
		</fo:block>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="eCH-0010:locality" mode="block">
		<fo:block>
			<xsl:value-of select="."/>
		</fo:block>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="eCH-0010:town" mode="block">
		<fo:block>
			<xsl:if test="../eCH-0010:country">
				<xsl:value-of select="concat(../eCH-0010:country, '-')"/>
			</xsl:if>
			<xsl:if test="../eCH-0010:swissZipCode">
				<xsl:value-of select="concat(../eCH-0010:swissZipCode, ' ')"/>
			</xsl:if>
			<xsl:if test="../eCH-0010:foreignZipCode">
				<xsl:value-of select="concat(../eCH-0010:foreignZipCode, ' ')"/>
			</xsl:if>
			<xsl:value-of select="."/>
			<xsl:if test="../eCH-0010:swissZipCodeAddOn">
				<xsl:value-of select="concat(' ', ../eCH-0010:swissZipCodeAddOn)"/>
			</xsl:if>
		</fo:block>
	</xsl:template>
	<!-- helper template for outputting an eCH-0010:addressInfoType as a block -->
	<xsl:template match="*" mode="block">
	</xsl:template>
	<!-- helper template for formatting ssk-common.taxMunicipality -->
	<xsl:template match="eahv-iv-common:taxMunicipality">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="concat($eahv-iv-common.taxMunicipality, ' (', $eCH-0007.municipalityId, ')')"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="eCH-0007:municipalityId"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.maritalStatus -->
	<xsl:template match="eahv-iv-common:maritalStatus">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.maritalStatus"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="decode-maritalStatusType">
						<xsl:with-param name="value" select="."/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.religion -->
	<xsl:template match="eahv-iv-common:religion">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.religion"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="decode-religionType">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.dateOfMaritalStatus -->
	<xsl:template match="eahv-iv-common:dateOfMaritalStatus">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.dateOfMaritalStatus"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-date">
						<xsl:with-param name="value" select="."/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.nbrOfChildren -->
	<xsl:template match="eahv-iv-common:nbrOfChildren">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.nbrOfChildren"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-string">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.dateOfDeath -->
	<xsl:template match="eahv-iv-common:dateOfDeath">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.dateOfDeath"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-date">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.municipality -->
	<xsl:template match="eahv-iv-common:municipality">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.municipality"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="concat(eahv-iv-common:zipCode, ' ', eahv-iv-common:name)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.landRegister -->
	<xsl:template match="eahv-iv-common:landRegister">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.landRegister"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="concat(eahv-iv-common:name, ', Parzelle ', eahv-iv-common:number)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.typeOfRealEstateProperty -->
	<xsl:template match="eahv-iv-common:typeOfRealEstateProperty">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.typeOfRealEstateProperty"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="decode-typeOfRealEstateProperty">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.share -->
	<xsl:template match="eahv-iv-common:share">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.share"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="."/>
					%
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.yearOfConstruction -->
	<xsl:template match="eahv-iv-common:yearOfConstruction">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.yearOfConstruction"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-string">
						<xsl:with-param name="value">
							<xsl:value-of select="."/>
						</xsl:with-param>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.landSurfaceArea -->
	<xsl:template match="eahv-iv-common:landSurfaceArea">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.landSurfaceArea"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="format-number(., $integer-format)"/>
					m&#0178;
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.taxableValueCanton -->
	<xsl:template match="eahv-iv-common:taxableValueCanton">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.taxableValueCanton"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="format-number(eahv-iv-common:amount, $integer-format)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.notionalRentalValueCanton -->
	<xsl:template match="eahv-iv-common:notionalRentalValueCanton">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.notionalRentalValueCanton"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="format-number(eahv-iv-common:amount, $integer-format)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.notionalRentalValueFederalTax -->
	<xsl:template match="eahv-iv-common:notionalRentalValueFederalTax">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.notionalRentalValueFederalTax"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="format-number(eahv-iv-common:amount, $integer-format)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- helper template for formatting ssk-common.grossEarnings -->
	<xsl:template match="eahv-iv-common:grossEarnings">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.grossEarnings"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="format-number(., $integer-format)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="eahv-iv-common:codeDescription">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.codeDescription"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="//eahv-iv-common:codeDescription"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="eahv-iv-common:faultyField">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.faultyField"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="//eahv-iv-common:faultyField"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="eahv-iv-common:timestamp">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.timestamp"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:call-template name="format-date">
						<xsl:with-param name="value" select="//eahv-iv-common:timestamp"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="eahv-iv-common:comment">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.comment"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<!--  <xsl:value-of select="//eahv-iv-common:comment" /> -->
					<xsl:call-template name="split">
						<xsl:with-param name="text" select="//eahv-iv-common:comment"/>
						<xsl:with-param name="size" select="2000"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="split">
		<xsl:param name="text"/>
		<xsl:param name="size"/>
		<xsl:param name="separator" select="' '"/>
		<xsl:choose>
			<xsl:when test="string-length($text) &lt;= $size">
				<fo:block>
					<xsl:value-of select="$text"/>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>
					<xsl:value-of select="concat(substring($text, 1, $size), $separator)"/>
				</fo:block>
				<xsl:call-template name="split">
					<xsl:with-param name="text" select="substring($text, $size + 1)"/>
					<xsl:with-param name="size" select="$size"/>
					<xsl:with-param name="separator" select="$separator"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="eahv-iv-common:xsdVersion">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.xsdVersion"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="//eahv-iv-common:xsdVersion"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="eahv-iv-common:additionalData">
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.additionalData"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:value-of select="//eahv-iv-common:additionalData"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<xsl:template name="eahv-iv-common:errorCodes">
		<!-- 	<fo:table table-layout="fixed" width="100%"
			page-break-inside="avoid" space-after="{$space-after-blocks}"
			border-collapse="separate">
			<fo:table-column column-width="{$title-column-width}"
				column-number="1" />
			<fo:table-column column-width="proportional-column-width(1)"
				column-number="2" />
			<fo:table-body> -->
		<fo:table-row>
			<fo:table-cell column-number="1" xsl:use-attribute-sets="denom-column">
				<fo:block>
					<xsl:value-of select="$eahv-iv-common.errorCode"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell column-number="2" xsl:use-attribute-sets="value-column">
				<fo:block>
					<xsl:choose>
						<xsl:when test="eahv-iv-common:negativeReport">
							<xsl:value-of select="//eahv-iv-common:negativeReport/eahv-iv-common:notice/eahv-iv-common:code"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:choose>
								<xsl:when test="eahv-iv-common:positiveReport">
									<xsl:value-of select="//eahv-iv-common:positiveReport/eahv-iv-common:notice/eahv-iv-common:code"/>
								</xsl:when>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<!--	</fo:table-body>
		</fo:table> -->
	</xsl:template>
	<xsl:template name="contactInformation">
		<fo:block>eahv-iv-common:contactInformation1</fo:block>
		<xsl:apply-templates select="eahv-iv-common:extension"/>
	</xsl:template>
	<xsl:template match="extension">
		<fo:block>eahv-iv-common:extension</fo:block>
		<xsl:apply-templates select="//eahv-iv-common:contactInformation"/>
	</xsl:template>
	<!-- 	<xsl:template match="eahv-iv-common:contactInformation"> -->
	<!-- 		<fo:block>eahv-iv-common:contactInformation</fo:block> -->
	<!-- 		<fo:block> -->
	<!-- 			<xsl:call-template name="format-string"> -->
	<!-- 				<xsl:with-param name="value" select="eahv-iv-common:name" /> -->
	<!-- 			</xsl:call-template> -->
	<!-- 		</fo:block> -->
	<!-- 		<fo:block> -->
	<!-- 			<xsl:call-template name="format-string"> -->
	<!-- 				<xsl:with-param name="value" select="eahv-iv-common:department" /> -->
	<!-- 			</xsl:call-template> -->
	<!-- 		</fo:block> -->
	<!-- 		<fo:block> -->
	<!-- 			T: -->
	<!-- 			<xsl:call-template name="format-string"> -->
	<!-- 				<xsl:with-param name="value" select="eahv-iv-common:phone" /> -->
	<!-- 			</xsl:call-template> -->
	<!-- 		</fo:block> -->
	<!-- 		<fo:block> -->
	<!-- 			<xsl:call-template name="format-string"> -->
	<!-- 				<xsl:with-param name="value" select="eahv-iv-common:email" /> -->
	<!-- 			</xsl:call-template>y -->
	<!-- 		</fo:block> -->
	<!-- 	</xsl:template> -->
	<!-- decode error and warning messages -->
	<xsl:template name="decode-errorMessages">
		<xsl:param name="value"/>
		<xsl:variable name="trimmed-value" select="normalize-space($value)"/>
		<xsl:choose>
			<xsl:when test="$trimmed-value = '00000'">
				<xsl:value-of select="$eahv-iv-common.correctCode.01"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'W0001'">
				<xsl:value-of select="$eahv-iv-common.warningCode.01"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'W0002'">
				<xsl:value-of select="$eahv-iv-common.warningCode.02"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0001'">
				<xsl:value-of select="$eahv-iv-common.errorCode.01"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0002'">
				<xsl:value-of select="$eahv-iv-common.errorCode.02"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0003'">
				<xsl:value-of select="$eahv-iv-common.errorCode.03"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0004'">
				<xsl:value-of select="$eahv-iv-common.errorCode.04"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0005'">
				<xsl:value-of select="$eahv-iv-common.errorCode.05"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0006'">
				<xsl:value-of select="$eahv-iv-common.errorCode.06"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0007'">
				<xsl:value-of select="$eahv-iv-common.errorCode.07"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0008'">
				<xsl:value-of select="$eahv-iv-common.errorCode.08"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0009'">
				<xsl:value-of select="$eahv-iv-common.errorCode.09"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0010'">
				<xsl:value-of select="$eahv-iv-common.errorCode.10"/>
			</xsl:when>
			<xsl:when test="$trimmed-value = 'E0999'">
				<xsl:value-of select="$eahv-iv-common.errorCode.999"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
